@@ -380,8 +380,10 @@ function cal_sql_create_event_do($calendarID, $event)
                             date('Y-m-d H:i:s', $event->lastUpdatedOn()),
 // newlines need more encoding when going into database
 //                            $event->getICal(TRUE),
+//                            $db->escapeSimple($event->getICal(TRUE)),
+                            $db->escapeSimple(
                             (empty($newline_regexp) ? $event->getICal(TRUE) 
-                            : preg_replace($newline_regexp, '##SQ_CAL_NL##', $event->getICal(TRUE))),
+                            : preg_replace($newline_regexp, '##SQ_CAL_NL##', $event->getICal(TRUE)))),
                             $calendarID), $sql);
 
 
@@ -668,8 +670,10 @@ function cal_sql_update_event_do($calendarID, $event)
                             date('Y-m-d H:i:s', $event->lastUpdatedOn()),
 // newlines need more encoding when going into database
 //                            $event->getICal(TRUE),
+//                            $db->escapeSimple($event->getICal(TRUE)),
+                            $db->escapeSimple(
                             (empty($newline_regexp) ? $event->getICal(TRUE) 
-                            : preg_replace($newline_regexp, '##SQ_CAL_NL##', $event->getICal(TRUE))),
+                            : preg_replace($newline_regexp, '##SQ_CAL_NL##', $event->getICal(TRUE)))),
                             $calendarID), $sql);
 
 
