@@ -79,7 +79,7 @@ if (!defined('SM_PATH'))
 function calendar_sql_backend_version() 
 {
 
-   return '1.0';
+   return '1.1-2.0';
 
 }
 
